Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1209)

Unified Diff: chrome/browser/chromeos/login/login_status_consumer.h

Issue 12704002: Support for auth code based authentication flow for both app and web UI driven flow. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/login/login_status_consumer.h
diff --git a/chrome/browser/chromeos/login/login_status_consumer.h b/chrome/browser/chromeos/login/login_status_consumer.h
index c82d1acdc4a8cb929a3d368484ed156572917570..b6efc61ddcbaddde7d9baeeadbbdee24ff49bc5e 100644
--- a/chrome/browser/chromeos/login/login_status_consumer.h
+++ b/chrome/browser/chromeos/login/login_status_consumer.h
@@ -14,6 +14,8 @@
namespace chromeos {
+struct UserCredentials;
+
class LoginFailure {
public:
enum FailureReason {
@@ -115,12 +117,11 @@ class LoginStatusConsumer {
// Unless overridden for special processing, this should always call
// OnLoginSuccess with the magic |kRetailModeUserEMail| constant.
virtual void OnRetailModeLoginSuccess();
// The current login attempt has succeeded for
// |username|/|password|. If |pending_requests| is false, we're totally done.
// If it's true, we will still have some more results to report later.
virtual void OnLoginSuccess(
- const std::string& username,
- const std::string& password,
+ const UserCredentials& credentials,
bool pending_requests,
bool using_oauth) = 0;
// The current guest login attempt has succeeded.
@@ -115,12 +117,11 @@ class LoginStatusConsumer {
// OnLoginSuccess with the magic |kRetailModeUserEMail| constant.
virtual void OnRetailModeLoginSuccess();
- // The current login attempt has succeeded for
- // |username|/|password|. If |pending_requests| is false, we're totally done.
+ // The current login attempt has succeeded for |credentials|.
+ // If |pending_requests| is false, we're totally done.
// If it's true, we will still have some more results to report later.
virtual void OnLoginSuccess(

Powered by Google App Engine
This is Rietveld 408576698